<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Centers;

class CentersController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'centers.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Centers::query()
            ->leftjoin('departments', 'centers.department', 'departments.id')
            ->select('centers.id', 'centers.country', 'departments.name as departments_name', 'centers.name', 'centers.created_at')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($column == 'centers.created_at') {
                $search = Util::formatDateStr($search, 'datetime');
            }
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $centerses = $query->paginate($size);
        return view('centerses.index', ['centerses' => $centerses]);
    }

    public function create()
    {
        $countries = DB::table('Country')
            ->select('Country.id', 'Country.name')
            ->get();
        $departmentses = DB::table('departments')
            ->select('departments.id', 'departments.name')
            ->get();
        return view('centerses.create', ['ref' => Util::getRef('/centerses'), 'countries' => $countries, 'departmentses' => $departmentses]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'name' => 'max:50',
            'state' => 'max:50',
            'city' => 'max:50',
            'street' => 'max:50',
            'phone_number' => 'max:50',
            'readable_id' => 'max:50'
        ]);
        Centers::create([
            'department' => request()->input('department'),
            'country' => request()->input('country'),
            'name' => request()->input('name'),
            'state' => request()->input('state'),
            'city' => request()->input('city'),
            'street' => request()->input('street'),
            'phone_number' => request()->input('phone_number'),
            'is_messaging_enabled' => request()->input('is_messaging_enabled'),
            'can_teacher_remove_students' => request()->input('can_teacher_remove_students'),
            'request_permission_for_halaqa_creation' => request()->input('request_permission_for_halaqa_creation'),
            'can_teachers_edit_students' => request()->input('can_teachers_edit_students'),
            'readable_id' => request()->input('readable_id'),
            'student_roaming' => request()->input('student_roaming'),
            'next_halaqa_readable_id' => request()->input('next_halaqa_readable_id')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $centers = Centers::query()
            ->leftjoin('Country', 'centers.country', 'Country.id')
            ->leftjoin('departments', 'centers.department', 'departments.id')
            ->leftjoin('UserAccount', 'centers.created_by_id', 'UserAccount.id')
            ->select('centers.id', 'Country.name as country_name', 'departments.name as departments_name', 'centers.name', 'centers.phone_number', 'centers.state', 'centers.city', 'centers.is_messaging_enabled', 'centers.can_teacher_remove_students', 'centers.request_permission_for_halaqa_creation', 'centers.street', 'centers.can_teachers_edit_students', 'UserAccount.name as user_account_name', 'centers.readable_id', 'centers.student_roaming', 'centers.next_halaqa_readable_id', 'centers.created_at')
            ->where('centers.id', $id)
            ->first();
        return view('centerses.show', ['centers' => $centers, 'ref' => Util::getRef('/centerses')]);
    }

    public function edit($id)
    {
        $centers = Centers::query()
            ->select('centers.id', 'centers.country', 'centers.department', 'centers.city', 'centers.state', 'centers.is_messaging_enabled', 'centers.can_teacher_remove_students', 'centers.request_permission_for_halaqa_creation', 'centers.phone_number', 'centers.street', 'centers.can_teachers_edit_students', 'centers.readable_id', 'centers.name', 'centers.student_roaming', 'centers.next_halaqa_readable_id')
            ->where('centers.id', $id)
            ->first();
        $departmentses = DB::table('departments')
            ->select('departments.id', 'departments.name')
            ->get();
        $countries = DB::table('Country')
            ->select('Country.id', 'Country.name')
            ->get();
        return view('centerses.edit', ['centers' => $centers, 'ref' => Util::getRef('/centerses'), 'departmentses' => $departmentses, 'countries' => $countries]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'city' => 'max:50',
            'state' => 'max:50',
            'phone_number' => 'max:50',
            'street' => 'max:50',
            'readable_id' => 'max:50',
            'name' => 'max:50'
        ]);
        Centers::find($id)->update([
            'country' => request()->input('country'),
            'department' => request()->input('department'),
            'city' => request()->input('city'),
            'state' => request()->input('state'),
            'is_messaging_enabled' => request()->input('is_messaging_enabled'),
            'can_teacher_remove_students' => request()->input('can_teacher_remove_students'),
            'request_permission_for_halaqa_creation' => request()->input('request_permission_for_halaqa_creation'),
            'phone_number' => request()->input('phone_number'),
            'street' => request()->input('street'),
            'can_teachers_edit_students' => request()->input('can_teachers_edit_students'),
            'readable_id' => request()->input('readable_id'),
            'name' => request()->input('name'),
            'student_roaming' => request()->input('student_roaming'),
            'next_halaqa_readable_id' => request()->input('next_halaqa_readable_id')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Centers::find($id)->delete();
        return back();
    }
}