<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Country;

class CountryController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'Country.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Country::query()
            ->select('Country.id', 'Country.code', 'Country.name')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $countries = $query->paginate($size);
        return view('countries.index', ['countries' => $countries]);
    }

    public function create()
    {
        return view('countries.create', ['ref' => Util::getRef('/countries')]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'id' => 'unique:Country,id|required',
            'code' => 'max:50',
            'name' => 'max:50'
        ]);
        Country::create([
            'id' => request()->input('id'),
            'code' => request()->input('code'),
            'name' => request()->input('name')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $country = Country::query()
            ->select('Country.id', 'Country.code', 'Country.name')
            ->where('Country.id', $id)
            ->first();
        return view('countries.show', ['country' => $country, 'ref' => Util::getRef('/countries')]);
    }

    public function edit($id)
    {
        $country = Country::query()
            ->select('Country.id', 'Country.code', 'Country.name')
            ->where('Country.id', $id)
            ->first();
        return view('countries.edit', ['country' => $country, 'ref' => Util::getRef('/countries')]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'id' => 'required',
            'code' => 'max:50',
            'name' => 'max:50'
        ]);
        Country::find($id)->update([
            'id' => request()->input('id'),
            'code' => request()->input('code'),
            'name' => request()->input('name')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Country::find($id)->delete();
        return back();
    }
}