<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Departments;

class DepartmentsController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'departments.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Departments::query()
            ->leftjoin('UserAccount', 'departments.centralAdmin', 'UserAccount.id')
            ->leftjoin('UserAccount as UserAccount2', 'departments.depAdmin', 'UserAccount2.id')
            ->leftjoin('UserAccount as UserAccount3', 'departments.createdBy', 'UserAccount3.id')
            ->select('departments.id', 'departments.name', 'departments.state', 'UserAccount.name as user_account_name', 'UserAccount2.name as user_account_name2', 'UserAccount3.name as user_account_name2')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $departmentses = $query->paginate($size);
        return view('departmentses.index', ['departmentses' => $departmentses]);
    }

    public function create()
    {
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        return view('departmentses.create', ['ref' => Util::getRef('/departmentses'), 'userAccounts' => $userAccounts]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'name' => 'max:50'
        ]);
        Departments::create([
            'centralAdmin' => request()->input('centralAdmin'),
            'depAdmin' => request()->input('depAdmin'),
            'name' => request()->input('name'),
            'state' => request()->input('state')
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $departments = Departments::query()
            ->leftjoin('UserAccount', 'departments.centralAdmin', 'UserAccount.id')
            ->leftjoin('UserAccount as UserAccount2', 'departments.depAdmin', 'UserAccount2.id')
            ->leftjoin('UserAccount as UserAccount3', 'departments.createdBy', 'UserAccount3.id')
            ->select('departments.id', 'departments.name', 'departments.state', 'UserAccount.name as user_account_name', 'UserAccount2.name as user_account_name2', 'UserAccount3.name as user_account_name2')
            ->where('departments.id', $id)
            ->first();
        return view('departmentses.show', ['departments' => $departments, 'ref' => Util::getRef('/departmentses')]);
    }

    public function edit($id)
    {
        $departments = Departments::query()
            ->select('departments.id', 'departments.centralAdmin', 'departments.depAdmin', 'departments.name', 'departments.state')
            ->where('departments.id', $id)
            ->first();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        return view('departmentses.edit', ['departments' => $departments, 'ref' => Util::getRef('/departmentses'), 'userAccounts' => $userAccounts]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'name' => 'max:50'
        ]);
        Departments::find($id)->update([
            'centralAdmin' => request()->input('centralAdmin'),
            'depAdmin' => request()->input('depAdmin'),
            'name' => request()->input('name'),
            'state' => request()->input('state')
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Departments::find($id)->delete();
        return back();
    }
}