<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Evaluation;

class EvaluationController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'evaluation.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Evaluation::query()
            ->leftjoin('quran', 'evaluation.fromSouraMem', 'quran.id')
            ->leftjoin('quran as quran2', 'evaluation.toSouraMem', 'quran2.id')
            ->leftjoin('instances', 'evaluation.instanceId', 'instances.id')
            ->leftjoin('UserAccount', 'evaluation.studentId', 'UserAccount.id')
            ->select('evaluation.id', 'evaluation.instanceId', 'evaluation.fromAyaMem', 'evaluation.toAyaMem', 'evaluation.mark', 'evaluation.pages', 'evaluation.fromAyaReh', 'evaluation.toAyaReh', 'quran.soura as quran_soura', 'quran2.soura as quran_soura2', 'instances.id as instances_id', 'UserAccount.name as user_account_name')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $evaluations = $query->paginate($size);
        return view('evaluations.index', ['evaluations' => $evaluations]);
    }

    public function create()
    {
        $instanceses = DB::table('instances')
            ->select('instances.id', 'instances.note')
            ->get();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        return view('evaluations.create', ['ref' => Util::getRef('/evaluations'), 'instanceses' => $instanceses, 'userAccounts' => $userAccounts]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
        ]);
        Evaluation::create([
            'instanceId' => request()->input('instanceId'),
            'fromAyaMem' => request()->input('fromAyaMem'),
            'fromSouraMem' => request()->input('fromSouraMem'),
            'toAyaMem' => request()->input('toAyaMem'),
            'toSouraMem' => request()->input('toSouraMem'),
            'mark' => request()->input('mark'),
            'pages' => request()->input('pages'),
            'fromAyaReh' => request()->input('fromAyaReh'),
            'fromSouraReh' => request()->input('fromSouraReh'),
            'toAyaReh' => request()->input('toAyaReh'),
            'toSouraReh' => request()->input('toSouraReh'),
            'studentId' => request()->input('studentId')
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $evaluation = Evaluation::query()
            ->select('evaluation.id', 'evaluation.instanceId', 'evaluation.fromAyaMem', 'evaluation.fromSouraMem', 'evaluation.toAyaMem', 'evaluation.toSouraMem', 'evaluation.mark', 'evaluation.pages', 'evaluation.fromAyaReh', 'evaluation.fromSouraReh', 'evaluation.toAyaReh', 'evaluation.toSouraReh', 'evaluation.studentId')
            ->where('evaluation.id', $id)
            ->first();
        return view('evaluations.show', ['evaluation' => $evaluation, 'ref' => Util::getRef('/evaluations')]);
    }

    public function edit($id)
    {
        $evaluation = Evaluation::query()
            ->select('evaluation.id', 'evaluation.instanceId', 'evaluation.fromAyaMem', 'evaluation.fromSouraMem', 'evaluation.toAyaMem', 'evaluation.toSouraMem', 'evaluation.mark', 'evaluation.pages', 'evaluation.fromAyaReh', 'evaluation.fromSouraReh', 'evaluation.toAyaReh', 'evaluation.toSouraReh', 'evaluation.studentId')
            ->where('evaluation.id', $id)
            ->first();
        $instanceses = DB::table('instances')
            ->select('instances.id', 'instances.note')
            ->get();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        return view('evaluations.edit', ['evaluation' => $evaluation, 'ref' => Util::getRef('/evaluations'), 'instanceses' => $instanceses, 'userAccounts' => $userAccounts]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
        ]);
        Evaluation::find($id)->update([
            'instanceId' => request()->input('instanceId'),
            'fromAyaMem' => request()->input('fromAyaMem'),
            'fromSouraMem' => request()->input('fromSouraMem'),
            'toAyaMem' => request()->input('toAyaMem'),
            'toSouraMem' => request()->input('toSouraMem'),
            'mark' => request()->input('mark'),
            'pages' => request()->input('pages'),
            'fromAyaReh' => request()->input('fromAyaReh'),
            'fromSouraReh' => request()->input('fromSouraReh'),
            'toAyaReh' => request()->input('toAyaReh'),
            'toSouraReh' => request()->input('toSouraReh'),
            'studentId' => request()->input('studentId')
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Evaluation::find($id)->delete();
        return back();
    }
}