<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Exam;

class ExamController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'exam.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Exam::query()
            ->leftjoin('halaqat', 'exam.halaqaId', 'halaqat.id')
            ->leftjoin('UserAccount', 'exam.teacherId', 'UserAccount.id')
            ->leftjoin('UserAccount as UserAccount2', 'exam.studentId', 'UserAccount2.id')
            ->select('exam.id', 'exam.studentNote', 'exam.subject', 'exam.status', 'exam.halaqaId', 'halaqat.name as halaqat_name', 'UserAccount.name as user_account_name', 'UserAccount2.name as user_account_name2')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $exams = $query->paginate($size);
        return view('exams.index', ['exams' => $exams]);
    }

    public function create()
    {
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.level')
            ->get();
        return view('exams.create', ['ref' => Util::getRef('/exams'), 'userAccounts' => $userAccounts, 'halaqats' => $halaqats]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'subject' => 'max:120',
            'status' => 'max:50'
        ]);
        Exam::create([
            'studentId' => request()->input('studentId'),
            'studentNote' => request()->input('studentNote'),
            'subject' => request()->input('subject'),
            'status' => request()->input('status'),
            'teacherId' => request()->input('teacherId'),
            'halaqaId' => request()->input('halaqaId')
            ,'create_user' => Auth::id()
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $exam = Exam::query()
            ->select('exam.id', 'exam.studentId', 'exam.studentNote', 'exam.subject', 'exam.status', 'exam.teacherId', 'exam.halaqaId')
            ->where('exam.id', $id)
            ->first();
        return view('exams.show', ['exam' => $exam, 'ref' => Util::getRef('/exams')]);
    }

    public function edit($id)
    {
        $exam = Exam::query()
            ->select('exam.id', 'exam.studentId', 'exam.studentNote', 'exam.subject', 'exam.status', 'exam.teacherId', 'exam.halaqaId')
            ->where('exam.id', $id)
            ->first();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.level')
            ->get();
        return view('exams.edit', ['exam' => $exam, 'ref' => Util::getRef('/exams'), 'userAccounts' => $userAccounts, 'halaqats' => $halaqats]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'subject' => 'max:120',
            'status' => 'max:50'
        ]);
        Exam::find($id)->update([
            'studentId' => request()->input('studentId'),
            'studentNote' => request()->input('studentNote'),
            'subject' => request()->input('subject'),
            'status' => request()->input('status'),
            'teacherId' => request()->input('teacherId'),
            'halaqaId' => request()->input('halaqaId')
            ,'update_user' => Auth::id()
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Exam::find($id)->delete();
        return back();
    }
}