<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Halaqat;
use App\Models\StudentHalaqat;

class HalaqatController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'halaqat.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Halaqat::query()
            ->leftjoin('centers', 'halaqat.center_id', 'centers.id')
            ->select('halaqat.id', 'halaqat.center_id', 'halaqat.level', 'halaqat.name', 'halaqat.description', 'halaqat.state', 'centers.name as centers_name', 'centers.id as centers_id')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $halaqats = $query->paginate($size);
        return view('halaqats.index', ['halaqats' => $halaqats]);
    }

    public function create()
    {
        $centerses = DB::table('centers')
            ->select('centers.id', 'centers.name')
            ->get();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        return view('halaqats.create', ['ref' => Util::getRef('/halaqats'), 'centerses' => $centerses, 'userAccounts' => $userAccounts]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'level' => 'max:50',
            'name' => 'max:50',
            'description' => 'max:50'
        ]);
        $halaqat = Halaqat::create([
            'center_id' => request()->input('center_id'),
            'level' => request()->input('level'),
            'name' => request()->input('name'),
            'description' => request()->input('description'),
            'state' => request()->input('state')
            ,'create_user' => Auth::id()
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        $halaqats = request()->input('studentId');
        if ($halaqats) {
            foreach ($halaqats as $_halaqat) {
                StudentHalaqat::create([
                    'studentId' => $_halaqat,
                    'halaqatId' => $halaqat->id
                ]);
            }
        }
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $halaqat = Halaqat::query()
            ->select('halaqat.id', 'halaqat.center_id', 'halaqat.level', 'halaqat.name', 'halaqat.description', 'halaqat.state')
            ->where('halaqat.id', $id)
            ->first();
        return view('halaqats.show', ['halaqat' => $halaqat, 'ref' => Util::getRef('/halaqats')]);
    }

    public function edit($id)
    {
        $halaqat = Halaqat::query()
            ->select('halaqat.id', 'halaqat.center_id', 'halaqat.level', 'halaqat.name', 'halaqat.description', 'halaqat.state')
            ->where('halaqat.id', $id)
            ->first();
        $halaqatStudentHalaqats = DB::table('halaqat')
            ->join('studentHalaqat', 'halaqat.id', 'studentHalaqat.halaqatId')
            ->select('studentHalaqat.studentId')
            ->where('halaqat.id', $id)
            ->get();
        $centerses = DB::table('centers')
            ->select('centers.id', 'centers.city')
            ->get();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        return view('halaqats.edit', ['halaqat' => $halaqat, 'ref' => Util::getRef('/halaqats'), 'halaqatStudentHalaqats' => $halaqatStudentHalaqats, 'centerses' => $centerses, 'userAccounts' => $userAccounts]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'level' => 'max:50',
            'name' => 'max:50',
            'description' => 'max:50'
        ]);
        Halaqat::find($id)->update([
            'center_id' => request()->input('center_id'),
            'level' => request()->input('level'),
            'name' => request()->input('name'),
            'description' => request()->input('description'),
            'state' => request()->input('state')
            ,'update_user' => Auth::id()
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        DB::table('studentHalaqat')
            ->where('studentHalaqat.halaqatId', $id)
            ->delete();
        $halaqats = request()->input('studentId');
        if ($halaqats) {
            foreach ($halaqats as $_halaqat) {
                StudentHalaqat::create([
                    'studentId' => $_halaqat,
                    'halaqatId' => $id
                ]);
            }
        }
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Halaqat::find($id)->delete();
        return back();
    }
}