<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Instances;

class InstancesController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'instances.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Instances::query()
            ->leftjoin('halaqat', 'instances.halaqaId', 'halaqat.id')
            ->select('instances.id', 'instances.note', 'halaqat.name as halaqat_name', 'instances.create_date')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($column == 'instances.create_date') {
                $search = Util::formatDateStr($search, 'datetime');
            }
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $instanceses = $query->paginate($size);
        return view('instanceses.index', ['instanceses' => $instanceses]);
    }

    public function create()
    {
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.level')
            ->get();
        return view('instanceses.create', ['ref' => Util::getRef('/instanceses'), 'halaqats' => $halaqats]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'note' => 'max:50'
        ]);
        Instances::create([
            'halaqaId' => request()->input('halaqaId'),
            'note' => request()->input('note')
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $instances = Instances::query()
            ->leftjoin('halaqat', 'instances.halaqaId', 'halaqat.id')
            ->select('instances.id', 'instances.note', 'halaqat.name as halaqat_name')
            ->where('instances.id', $id)
            ->first();
        return view('instanceses.show', ['instances' => $instances, 'ref' => Util::getRef('/instanceses')]);
    }

    public function edit($id)
    {
        $instances = Instances::query()
            ->select('instances.id', 'instances.halaqaId', 'instances.note')
            ->where('instances.id', $id)
            ->first();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.level')
            ->get();
        return view('instanceses.edit', ['instances' => $instances, 'ref' => Util::getRef('/instanceses'), 'halaqats' => $halaqats]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'note' => 'max:50'
        ]);
        Instances::find($id)->update([
            'halaqaId' => request()->input('halaqaId'),
            'note' => request()->input('note')
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Instances::find($id)->delete();
        return back();
    }
}