<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Quran;

class QuranController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'quran.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Quran::query()
            ->select('quran.id', 'quran.soura', 'quran.nbrAya')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $qurans = $query->paginate($size);
        return view('qurans.index', ['qurans' => $qurans]);
    }

    public function create()
    {
        return view('qurans.create', ['ref' => Util::getRef('/qurans')]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'soura' => 'max:50'
        ]);
        Quran::create([
            'soura' => request()->input('soura'),
            'nbrAya' => request()->input('nbrAya')
            ,'create_user' => Auth::id()
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $quran = Quran::query()
            ->select('quran.id', 'quran.soura', 'quran.nbrAya')
            ->where('quran.id', $id)
            ->first();
        return view('qurans.show', ['quran' => $quran, 'ref' => Util::getRef('/qurans')]);
    }

    public function edit($id)
    {
        $quran = Quran::query()
            ->select('quran.id', 'quran.soura', 'quran.nbrAya')
            ->where('quran.id', $id)
            ->first();
        return view('qurans.edit', ['quran' => $quran, 'ref' => Util::getRef('/qurans')]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'soura' => 'max:50'
        ]);
        Quran::find($id)->update([
            'soura' => request()->input('soura'),
            'nbrAya' => request()->input('nbrAya')
            ,'update_user' => Auth::id()
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Quran::find($id)->delete();
        return back();
    }
}