<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\ReportCard;

class ReportCardController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'reportCard.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = ReportCard::query()
            ->leftjoin('halaqat', 'reportCard.halaqaId', 'halaqat.id')
            ->leftjoin('UserAccount', 'reportCard.studentId', 'UserAccount.id')
            ->select('reportCard.id', 'reportCard.soura', 'reportCard.numbeOfAyatInSoura', 'reportCard.numberOfAyatMemorized', 'halaqat.name as halaqat_name', 'UserAccount.name as user_account_name', 'reportCard.precentage')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $reportCards = $query->paginate($size);
        return view('reportCards.index', ['reportCards' => $reportCards]);
    }

    public function create()
    {
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.name')
            ->get();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.name')
            ->get();
        return view('reportCards.create', ['ref' => Util::getRef('/reportCards'), 'userAccounts' => $userAccounts, 'halaqats' => $halaqats]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'soura' => 'max:50'
        ]);
        ReportCard::create([
            'studentId' => request()->input('studentId'),
            'precentage' => request()->input('precentage'),
            'soura' => request()->input('soura'),
            'numbeOfAyatInSoura' => request()->input('numbeOfAyatInSoura'),
            'numberOfAyatMemorized' => request()->input('numberOfAyatMemorized'),
            'halaqaId' => request()->input('halaqaId')
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $reportCard = ReportCard::query()
            ->select('reportCard.id', 'reportCard.studentId', 'reportCard.halaqaId', 'reportCard.precentage', 'reportCard.soura', 'reportCard.numbeOfAyatInSoura', 'reportCard.numberOfAyatMemorized')
            ->where('reportCard.id', $id)
            ->first();
        return view('reportCards.show', ['reportCard' => $reportCard, 'ref' => Util::getRef('/reportCards')]);
    }

    public function edit($id)
    {
        $reportCard = ReportCard::query()
            ->select('reportCard.id', 'reportCard.studentId', 'reportCard.halaqaId', 'reportCard.precentage', 'reportCard.soura', 'reportCard.numbeOfAyatInSoura', 'reportCard.numberOfAyatMemorized')
            ->where('reportCard.id', $id)
            ->first();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.level')
            ->get();
        return view('reportCards.edit', ['reportCard' => $reportCard, 'ref' => Util::getRef('/reportCards'), 'userAccounts' => $userAccounts, 'halaqats' => $halaqats]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'soura' => 'max:50'
        ]);
        ReportCard::find($id)->update([
            'studentId' => request()->input('studentId'),
            'halaqaId' => request()->input('halaqaId'),
            'precentage' => request()->input('precentage'),
            'soura' => request()->input('soura'),
            'numbeOfAyatInSoura' => request()->input('numbeOfAyatInSoura'),
            'numberOfAyatMemorized' => request()->input('numberOfAyatMemorized')
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        ReportCard::find($id)->delete();
        return back();
    }
}