<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\Settings;

class SettingsController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'Settings.facebook';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = Settings::query()
            ->select('Settings.facebook', 'Settings.insta', 'Settings.phone1', 'Settings.phone2', 'Settings.whatsup', 'Settings.appVersion', 'Settings.supportPage', 'Settings.privancyPage', 'Settings.termAndCOnditionPage', 'Settings.id')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $settingses = $query->paginate($size);
        return view('settingses.index', ['settingses' => $settingses]);
    }

    public function create()
    {
        return view('settingses.create', ['ref' => Util::getRef('/settingses')]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'facebook' => 'max:50',
            'insta' => 'max:50',
            'phone1' => 'max:50',
            'phone2' => 'max:50',
            'whatsup' => 'max:50',
            'id' => 'unique:Settings,id|required|max:50',
            'supportPage' => 'max:50',
            'privancyPage' => 'max:50',
            'termAndCOnditionPage' => 'max:50'
        ]);
        Settings::create([
            'facebook' => request()->input('facebook'),
            'insta' => request()->input('insta'),
            'phone1' => request()->input('phone1'),
            'phone2' => request()->input('phone2'),
            'whatsup' => request()->input('whatsup'),
            'appVersion' => request()->input('appVersion'),
            'id' => request()->input('id'),
            'supportPage' => request()->input('supportPage'),
            'privancyPage' => request()->input('privancyPage'),
            'termAndCOnditionPage' => request()->input('termAndCOnditionPage')
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $settings = Settings::query()
            ->select('Settings.facebook', 'Settings.insta', 'Settings.phone1', 'Settings.phone2', 'Settings.whatsup', 'Settings.appVersion', 'Settings.id', 'Settings.supportPage', 'Settings.privancyPage', 'Settings.termAndCOnditionPage')
            ->where('Settings.id', $id)
            ->first();
        return view('settingses.show', ['settings' => $settings, 'ref' => Util::getRef('/settingses')]);
    }

    public function edit($id)
    {
        $settings = Settings::query()
            ->select('Settings.facebook', 'Settings.insta', 'Settings.phone1', 'Settings.phone2', 'Settings.whatsup', 'Settings.appVersion', 'Settings.id', 'Settings.supportPage', 'Settings.privancyPage', 'Settings.termAndCOnditionPage')
            ->where('Settings.id', $id)
            ->first();
        return view('settingses.edit', ['settings' => $settings, 'ref' => Util::getRef('/settingses')]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'facebook' => 'max:50',
            'insta' => 'max:50',
            'phone1' => 'max:50',
            'phone2' => 'max:50',
            'whatsup' => 'max:50',
            'id' => 'required|max:50',
            'supportPage' => 'max:50',
            'privancyPage' => 'max:50',
            'termAndCOnditionPage' => 'max:50'
        ]);
        Settings::find($id)->update([
            'facebook' => request()->input('facebook'),
            'insta' => request()->input('insta'),
            'phone1' => request()->input('phone1'),
            'phone2' => request()->input('phone2'),
            'whatsup' => request()->input('whatsup'),
            'appVersion' => request()->input('appVersion'),
            'id' => request()->input('id'),
            'supportPage' => request()->input('supportPage'),
            'privancyPage' => request()->input('privancyPage'),
            'termAndCOnditionPage' => request()->input('termAndCOnditionPage')
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        Settings::find($id)->delete();
        return back();
    }
}