<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Validation\Rule;
use App\Util;
use App\Models\StudentHalaqat;

class StudentHalaqatController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'studentHalaqat.studentId';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = StudentHalaqat::query()
            ->select('studentHalaqat.studentId', 'studentHalaqat.halaqatId')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $studentHalaqats = $query->paginate($size);
        return view('studentHalaqats.index', ['studentHalaqats' => $studentHalaqats]);
    }

    public function create()
    {
        return view('studentHalaqats.create', ['ref' => Util::getRef('/studentHalaqats')]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'studentId' => 'required',
            'halaqatId' => 'required'
        ]);
        $this->validate(request(), [ 'studentId' => Rule::unique('studentHalaqat', 'studentId')->where('studentId', request()->input('studentId'))->where('halaqatId', request()->input('halaqatId')) ]);
        StudentHalaqat::create([
            'studentId' => request()->input('studentId'),
            'halaqatId' => request()->input('halaqatId')
            ,'create_user' => Auth::id()
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($studentId, $halaqatId)
    {
        $studentHalaqat = StudentHalaqat::query()
            ->select('studentHalaqat.studentId', 'studentHalaqat.halaqatId')
            ->where('studentHalaqat.studentId', $studentId)
            ->where('studentHalaqat.halaqatId', $halaqatId)
            ->first();
        return view('studentHalaqats.show', ['studentHalaqat' => $studentHalaqat, 'ref' => Util::getRef('/studentHalaqats')]);
    }

    public function edit($studentId, $halaqatId)
    {
        $studentHalaqat = StudentHalaqat::query()
            ->select('studentHalaqat.studentId', 'studentHalaqat.halaqatId')
            ->where('studentHalaqat.studentId', $studentId)
            ->where('studentHalaqat.halaqatId', $halaqatId)
            ->first();
        return view('studentHalaqats.edit', ['studentHalaqat' => $studentHalaqat, 'ref' => Util::getRef('/studentHalaqats')]);
    }

    public function update($studentId, $halaqatId)
    {
        Util::setRef();
        $this->validate(request(), [
            'studentId' => 'required',
            'halaqatId' => 'required'
        ]);
        DB::table('studentHalaqat')
            ->where('studentHalaqat.studentId', $studentId)
            ->where('studentHalaqat.halaqatId', $halaqatId)
            ->update([
            'studentId' => request()->input('studentId'),
            'halaqatId' => request()->input('halaqatId')
            ,'update_user' => Auth::id()
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($studentId, $halaqatId)
    {
        DB::table('studentHalaqat')
            ->where('studentHalaqat.studentId', $studentId)
            ->where('studentHalaqat.halaqatId', $halaqatId)
            ->delete();
        return back();
    }
}