<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Util;
use App\Models\StudentInstance;

class StudentInstanceController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'studentInstance.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = StudentInstance::query()
            ->leftjoin('UserAccount', 'studentInstance.StudentId', 'UserAccount.id')
            ->leftjoin('halaqat', 'studentInstance.HalaqatId', 'halaqat.id')
            ->select('studentInstance.id', 'studentInstance.note', 'UserAccount.name as user_account_name', 'halaqat.name as halaqat_name', 'studentInstance.state')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $studentInstances = $query->paginate($size);
        return view('studentInstances.index', ['studentInstances' => $studentInstances]);
    }

    public function create()
    {
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.level')
            ->get();
        return view('studentInstances.create', ['ref' => Util::getRef('/studentInstances'), 'userAccounts' => $userAccounts, 'halaqats' => $halaqats]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'note' => 'max:50',
            'state' => 'max:50'
        ]);
        StudentInstance::create([
            'StudentId' => request()->input('StudentId'),
            'HalaqatId' => request()->input('HalaqatId'),
            'note' => request()->input('note'),
            'state' => request()->input('state')
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $studentInstance = StudentInstance::query()
            ->leftjoin('halaqat', 'studentInstance.HalaqatId', 'halaqat.id')
            ->leftjoin('UserAccount', 'studentInstance.StudentId', 'UserAccount.id')
            ->select('studentInstance.id', 'studentInstance.note', 'studentInstance.state', 'halaqat.name as halaqat_name', 'UserAccount.name as user_account_name')
            ->where('studentInstance.id', $id)
            ->first();
        return view('studentInstances.show', ['studentInstance' => $studentInstance, 'ref' => Util::getRef('/studentInstances')]);
    }

    public function edit($id)
    {
        $studentInstance = StudentInstance::query()
            ->select('studentInstance.id', 'studentInstance.StudentId', 'studentInstance.HalaqatId', 'studentInstance.note', 'studentInstance.state')
            ->where('studentInstance.id', $id)
            ->first();
        $userAccounts = DB::table('UserAccount')
            ->select('UserAccount.id', 'UserAccount.name')
            ->get();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.level')
            ->get();
        return view('studentInstances.edit', ['studentInstance' => $studentInstance, 'ref' => Util::getRef('/studentInstances'), 'userAccounts' => $userAccounts, 'halaqats' => $halaqats]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'note' => 'max:50',
            'state' => 'max:50'
        ]);
        StudentInstance::find($id)->update([
            'StudentId' => request()->input('StudentId'),
            'HalaqatId' => request()->input('HalaqatId'),
            'note' => request()->input('note'),
            'state' => request()->input('state')
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        StudentInstance::find($id)->delete();
        return back();
    }
}