<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use App\Util;
use App\Models\UserAccount;
use App\Models\UserRole;
use App\Models\StudentHalaqat;

class UserAccountController extends Controller {

    public function index()
    {
        $size = request()->input('size') ? request()->input('size') : 10;
        $sort = request()->input('sort') ? request()->input('sort') : 'UserAccount.id';
        $sortDirection = request()->input('sort') ? (request()->input('desc') ? 'desc' : 'asc') : 'asc';
        $column = request()->input('sc');
        $query = UserAccount::query()
            ->select('UserAccount.id', 'UserAccount.name', 'UserAccount.email', 'UserAccount.password', 'UserAccount.active', 'UserAccount.gender', 'UserAccount.address', 'UserAccount.dateOfBirth', 'UserAccount.nationality', 'UserAccount.phoneNumber', 'UserAccount.parentPhoneNumber', 'UserAccount.note')
            ->orderBy($sort, $sortDirection);
        if (Util::IsInvalidSearch($query->getQuery()->columns, $column)) {
            abort(403);
        }
        if (request()->input('sw')) {
            $search = request()->input('sw');
            $operator = Util::getOperator(request()->input('so'));
            if ($column == 'UserAccount.dateOfBirth') {
                $search = Util::formatDateStr($search, 'date');
            }
            if ($operator == 'like') {
                $search = '%'.$search.'%';
            }
            $query->where($column, $operator, $search);
        }
        $userAccounts = $query->paginate($size);
        return view('userAccounts.index', ['userAccounts' => $userAccounts]);
    }

    public function create()
    {
        $countries = DB::table('Country')
            ->select('Country.id', 'Country.name')
            ->get();
        $roles = DB::table('Role')
            ->select('Role.id', 'Role.name')
            ->get();
        $halaqats = DB::table('halaqat')
            ->select('halaqat.id', 'halaqat.name')
            ->get();
        return view('userAccounts.create', ['ref' => Util::getRef('/userAccounts'), 'countries' => $countries, 'roles' => $roles, 'halaqats' => $halaqats]);
    }

    public function store()
    {
        Util::setRef();
        $this->validate(request(), [
            'name' => 'unique:UserAccount,name|required|max:50',
            'email' => 'unique:UserAccount,email|required|max:50',
            'password' => 'required|max:100',
            'gender' => 'max:50',
            'address' => 'max:50',
            'phoneNumber' => 'max:50',
            'parentPhoneNumber' => 'max:50',
            'note' => 'max:50'
        ]);
        $token = Str::random(40);
        $userAccount = UserAccount::create([
            'password_reset_token' => $token,
            'name' => request()->input('name'),
            'email' => request()->input('email'),
            'password' => request()->input('password') ? Hash::make(request()->input('password')) : request()->input('password'),
            'active' => Util::getRaw(request()->input('active') == null ? false : request()->input('active')),
            'gender' => request()->input('gender'),
            'address' => request()->input('address'),
            'dateOfBirth' => Util::getDate(request()->input('dateOfBirth')),
            'nationality' => request()->input('nationality'),
            'phoneNumber' => request()->input('phoneNumber'),
            'parentPhoneNumber' => request()->input('parentPhoneNumber'),
            'note' => request()->input('note')
            ,'create_user' => Auth::id()
            ,'create_date' => date('Y-m-d H:i:s')
        ]);
        $roles = request()->input('role_id');
        if ($roles) {
            foreach ($roles as $role) {
                UserRole::create([
                    'user_id' => $userAccount->id,
                    'role_id' => $role
                ]);
            }
        }
        $halaqats = request()->input('halaqatId');
        if ($halaqats) {
            foreach ($halaqats as $halaqat) {
                StudentHalaqat::create([
                    'studentId' => $userAccount->id,
                    'halaqatId' => $halaqat
                ]);
            }
        }
        Util::sentMail('WELCOME', $userAccount->email, $token, $userAccount->name);
        return redirect(request()->query->get('ref'));
    }

    public function show($id)
    {
        $userAccount = UserAccount::query()
            ->select('UserAccount.id', 'UserAccount.name', 'UserAccount.email', 'UserAccount.password', 'UserAccount.active', 'UserAccount.gender', 'UserAccount.address', 'UserAccount.dateOfBirth', 'UserAccount.nationality', 'UserAccount.phoneNumber', 'UserAccount.parentPhoneNumber', 'UserAccount.note')
            ->where('UserAccount.id', $id)
            ->first();
        return view('userAccounts.show', ['userAccount' => $userAccount, 'ref' => Util::getRef('/userAccounts')]);
    }

    public function edit($id)
    {
        $userAccount = UserAccount::query()
            ->select('UserAccount.id', 'UserAccount.name', 'UserAccount.email', 'UserAccount.active', 'UserAccount.gender', 'UserAccount.address', 'UserAccount.dateOfBirth', 'UserAccount.nationality', 'UserAccount.phoneNumber', 'UserAccount.parentPhoneNumber', 'UserAccount.note')
            ->where('UserAccount.id', $id)
            ->first();
        $countries = DB::table('Country')
            ->select('Country.id', 'Country.code')
            ->get();
        return view('userAccounts.edit', ['userAccount' => $userAccount, 'ref' => Util::getRef('/userAccounts'), 'countries' => $countries]);
    }

    public function update($id)
    {
        Util::setRef();
        $this->validate(request(), [
            'name' => 'required|max:50',
            'email' => 'required|max:50',
            'password' => 'max:100',
            'gender' => 'max:50',
            'address' => 'max:50',
            'phoneNumber' => 'max:50',
            'parentPhoneNumber' => 'max:50',
            'note' => 'max:50'
        ]);
        $userAccount = UserAccount::find($id);
        UserAccount::find($id)->update([
            'name' => request()->input('name'),
            'email' => request()->input('email'),
            'password' => request()->input('password') ? Hash::make(request()->input('password')) : $userAccount->password,
            'active' => Util::getRaw(request()->input('active') == null ? false : request()->input('active')),
            'gender' => request()->input('gender'),
            'address' => request()->input('address'),
            'dateOfBirth' => Util::getDate(request()->input('dateOfBirth')),
            'nationality' => request()->input('nationality'),
            'phoneNumber' => request()->input('phoneNumber'),
            'parentPhoneNumber' => request()->input('parentPhoneNumber'),
            'note' => request()->input('note')
            ,'update_user' => Auth::id()
            ,'update_date' => date('Y-m-d H:i:s')
        ]);
        return redirect(request()->query->get('ref'));
    }

    public function destroy($id)
    {
        UserAccount::find($id)->delete();
        return back();
    }
}